@@ -65,6 +65,11 @@ sqla_14_26 = _vers >= (1, 4, 26)
 sqla_2 = _vers >= (2,)
 sqlalchemy_version = __version__
 
+try:
+    from sqlalchemy.sql.naming import _NONE_NAME as _NONE_NAME
+except ImportError:
+    from sqlalchemy.sql.elements import _NONE_NAME as _NONE_NAME  # type: ignore  # noqa: E501
+
 
 if sqla_14:
     # when future engine merges, this can be again based on version string
@@ -111,15 +116,28 @@ if sqla_2:
 else:
     from sqlalchemy.util import symbol as _NoneName  # type: ignore[assignment]
 
+
 _ConstraintName = Union[None, str, _NoneName]
 
+_ConstraintNameDefined = Union[str, _NoneName]
 
-def constraint_name_defined(name: _ConstraintName) -> TypeGuard[str]:
+
+def constraint_name_defined(
+    name: _ConstraintName,
+) -> TypeGuard[_ConstraintNameDefined]:
+    return name is _NONE_NAME or isinstance(name, (str, _NoneName))
+
+
+def constraint_name_string(
+    name: _ConstraintName,
+) -> TypeGuard[str]:
     return isinstance(name, str)
 
 
-def constraint_name_or_none(name: _ConstraintName) -> Optional[str]:
-    return name if constraint_name_defined(name) else None
+def constraint_name_or_none(
+    name: _ConstraintName,
+) -> Optional[str]:
+    return name if constraint_name_string(name) else None
 
 
 AUTOINCREMENT_DEFAULT = "auto"
