@@ -5,9 +5,13 @@ from io import StringIO
 from io import TextIOWrapper
 import os
 import re
+from typing import cast
 
 from sqlalchemy import exc as sqla_exc
 from sqlalchemy import text
+from sqlalchemy import VARCHAR
+from sqlalchemy.engine import Engine
+from sqlalchemy.sql.schema import Column
 
 from alembic import __version__
 from alembic import command
@@ -85,7 +89,7 @@ try:
         context.run_migrations()
 finally:
     connection.close()
-
+    engine.dispose()
 """
         )
 
@@ -202,7 +206,7 @@ finally:
 class CurrentTest(_BufMixin, TestBase):
     @classmethod
     def setup_class(cls):
-        cls.bind = _sqlite_file_db()
+        cls.bind = _sqlite_file_db(scope="class")
         cls.env = env = staging_env()
         cls.cfg = _sqlite_testing_config()
         cls.a1 = env.generate_revision("a1", "a1")
@@ -222,15 +226,13 @@ class CurrentTest(_BufMixin, TestBase):
 
         yield
 
-        lines = set(
-            [
-                re.match(r"(^.\w)", elem).group(1)
-                for elem in re.split(
-                    "\n", buf.getvalue().decode("ascii", "replace").strip()
-                )
-                if elem
-            ]
-        )
+        lines = {
+            re.match(r"(^.\w)", elem).group(1)
+            for elem in re.split(
+                "\n", buf.getvalue().decode("ascii", "replace").strip()
+            )
+            if elem
+        }
 
         eq_(lines, set(revs))
 
@@ -254,7 +256,7 @@ class CurrentTest(_BufMixin, TestBase):
     def test_current_obfuscate_password(self):
         eq_(
             util.obfuscate_url_pw("postgresql://scott:tiger@localhost/test"),
-            "postgresql://scott:XXXXX@localhost/test",
+            "postgresql://scott:***@localhost/test",
         )
 
     def test_two_heads(self):
@@ -307,6 +309,7 @@ try:
         context.run_migrations()
 finally:
     connection.close()
+    engine.dispose()
 
 """
             % (version_table_pk,)
@@ -536,6 +539,63 @@ finally:
         command.revision(self.cfg, sql=True)
 
 
+class CheckTest(TestBase):
+    def setUp(self):
+        self.env = staging_env()
+        self.cfg = _sqlite_testing_config()
+
+    def tearDown(self):
+        clear_staging_env()
+
+    def _env_fixture(self, version_table_pk=True):
+        env_file_fixture(
+            """
+
+from sqlalchemy import MetaData, engine_from_config
+target_metadata = MetaData()
+
+engine = engine_from_config(
+    config.get_section(config.config_ini_section),
+    prefix='sqlalchemy.')
+
+connection = engine.connect()
+
+context.configure(
+    connection=connection, target_metadata=target_metadata,
+    version_table_pk=%r
+)
+
+try:
+    with context.begin_transaction():
+        context.run_migrations()
+finally:
+    connection.close()
+    engine.dispose()
+
+"""
+            % (version_table_pk,)
+        )
+
+    def test_check_no_changes(self):
+        self._env_fixture()
+        command.check(self.cfg)  # no problem
+
+    def test_check_changes_detected(self):
+        self._env_fixture()
+        with mock.patch(
+            "alembic.operations.ops.UpgradeOps.as_diffs",
+            return_value=[
+                ("remove_column", None, "foo", Column("old_data", VARCHAR()))
+            ],
+        ):
+            assert_raises_message(
+                util.AutogenerateDiffsDetected,
+                r"New upgrade operations detected: \[\('remove_column'",
+                command.check,
+                self.cfg,
+            )
+
+
 class _StampTest:
     def _assert_sql(self, emitted_sql, origin, destinations):
         ins_expr = (
@@ -1185,3 +1245,36 @@ class CommandLineTest(TestBase):
 
         is_true("test_prog" in str(buf.getvalue()))
         is_true(__version__ in str(buf.getvalue()))
+
+
+class EnureVersionTest(TestBase):
+    @classmethod
+    def setup_class(cls):
+        cls.bind = _sqlite_file_db(scope="class")
+        cls.env = staging_env()
+        cls.cfg = _sqlite_testing_config()
+
+    @classmethod
+    def teardown_class(cls):
+        clear_staging_env()
+
+    def test_ensure_version(self):
+        command.ensure_version(self.cfg)
+
+        engine = cast(Engine, self.bind)
+        with engine.connect() as conn:
+            is_true(_connectable_has_table(conn, "alembic_version", None))
+
+    def test_ensure_version_called_twice(self):
+        command.ensure_version(self.cfg)
+        command.ensure_version(self.cfg)
+
+        engine = cast(Engine, self.bind)
+        with engine.connect() as conn:
+            is_true(_connectable_has_table(conn, "alembic_version", None))
+
+    def test_sql_ensure_version(self):
+        with capture_context_buffer() as buf:
+            command.ensure_version(self.cfg, sql=True)
+
+        is_true(buf.getvalue().startswith("CREATE TABLE alembic_version"))
