@@ -3,12 +3,13 @@ from sqlalchemy import Column
 from sqlalchemy import DateTime
 from sqlalchemy import Float
 from sqlalchemy import func
+from sqlalchemy import Index
+from sqlalchemy import inspect
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
 from sqlalchemy import String
 from sqlalchemy import Table
 from sqlalchemy import text
-from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy.sql import column
 
 from alembic import autogenerate
@@ -21,10 +22,12 @@ from alembic.testing import assert_raises_message
 from alembic.testing import config
 from alembic.testing import eq_
 from alembic.testing import eq_ignore_whitespace
+from alembic.testing.assertions import expect_warnings
 from alembic.testing.env import clear_staging_env
 from alembic.testing.env import staging_env
 from alembic.testing.fixtures import op_fixture
 from alembic.testing.fixtures import TestBase
+from alembic.testing.suite._autogen_fixtures import AutogenFixtureTest
 
 
 class SQLiteTest(TestBase):
@@ -81,6 +84,11 @@ class SQLiteTest(TestBase):
         op.add_column("t1", Column("c1", Integer, comment="c1 comment"))
         context.assert_("ALTER TABLE t1 ADD COLUMN c1 INTEGER")
 
+    def test_rename_table_w_schema(self):
+        context = op_fixture("sqlite")
+        op.rename_table("old_name", "new_name", schema="my_schema")
+        context.assert_("ALTER TABLE my_schema.old_name RENAME TO new_name")
+
 
 class SQLiteDefaultCompareTest(TestBase):
     __only_on__ = "sqlite"
@@ -96,7 +104,7 @@ class SQLiteDefaultCompareTest(TestBase):
         )
 
     def setUp(self):
-        self.metadata = MetaData(self.bind)
+        self.metadata = MetaData()
         self.autogen_context = api.AutogenContext(self.migration_context)
 
     @classmethod
@@ -104,7 +112,7 @@ class SQLiteDefaultCompareTest(TestBase):
         clear_staging_env()
 
     def tearDown(self):
-        self.metadata.drop_all()
+        self.metadata.drop_all(config.db)
 
     def _compare_default_roundtrip(
         self, type_, orig_default, alternate=None, diff_expected=None
@@ -130,7 +138,7 @@ class SQLiteDefaultCompareTest(TestBase):
 
         t1.create(self.bind)
 
-        insp = Inspector.from_engine(self.bind)
+        insp = inspect(self.bind)
         cols = insp.get_columns(t1.name)
         insp_col = Column(
             "somecol", cols[0]["type"], server_default=text(cols[0]["default"])
@@ -151,7 +159,7 @@ class SQLiteDefaultCompareTest(TestBase):
 
     def _compare_default(self, t1, t2, col, rendered):
         t1.create(self.bind, checkfirst=True)
-        insp = Inspector.from_engine(self.bind)
+        insp = inspect(self.bind)
         cols = insp.get_columns(t1.name)
         ctx = self.autogen_context.migration_context
 
@@ -159,12 +167,14 @@ class SQLiteDefaultCompareTest(TestBase):
             None, col, rendered, cols[0]["default"]
         )
 
-    @config.requirements.sqlalchemy_12
     def test_compare_current_timestamp_func(self):
         self._compare_default_roundtrip(
             DateTime(), func.datetime("now", "localtime")
         )
 
+    def test_compare_current_timestamp_func_now(self):
+        self._compare_default_roundtrip(DateTime(), func.now())
+
     def test_compare_current_timestamp_text(self):
         # SQLAlchemy doesn't render the parenthesis for a
         # SQLite server default specified as text(), so users will be doing
@@ -228,7 +238,7 @@ class SQLiteAutogenRenderTest(TestBase):
         eq_ignore_whitespace(
             result,
             "sa.Column('date_value', sa.DateTime(), "
-            "server_default=sa.text(!U\"(datetime('now', 'localtime'))\"), "
+            "server_default=sa.text(\"(datetime('now', 'localtime'))\"), "
             "nullable=True)",
         )
 
@@ -243,7 +253,7 @@ class SQLiteAutogenRenderTest(TestBase):
         eq_ignore_whitespace(
             result,
             "sa.Column('date_value', sa.DateTime(), "
-            "server_default=sa.text(!U\"(datetime('now', 'localtime'))\"), "
+            "server_default=sa.text(\"(datetime('now', 'localtime'))\"), "
             "nullable=True)",
         )
 
@@ -267,3 +277,70 @@ class SQLiteAutogenRenderTest(TestBase):
             "sa.Column('int_value', sa.Integer(), "
             "nullable=True, sqlite_on_conflict_not_null='FAIL')",
         )
+
+
+class SQLiteAutogenIndexTest(AutogenFixtureTest, TestBase):
+    __requires__ = ("indexes_with_expressions",)
+    __only_on__ = "sqlite"
+    __backend__ = True
+
+    def _functional_index_warn(self):
+        return (r"Skip.*refl",)
+
+    def test_functional_ix_one(self):
+        m1 = MetaData()
+        m2 = MetaData()
+
+        t1 = Table(
+            "foo",
+            m1,
+            Column("id", Integer, primary_key=True),
+            Column("email", String(50)),
+        )
+        Index("email_idx", func.lower(t1.c.email), unique=True)
+
+        t2 = Table(
+            "foo",
+            m2,
+            Column("id", Integer, primary_key=True),
+            Column("email", String(50)),
+        )
+        Index("email_idx", func.lower(t2.c.email), unique=True)
+
+        with expect_warnings(*self._functional_index_warn()):
+            diffs = self._fixture(m1, m2)
+        eq_(diffs, [])
+
+    def test_functional_ix_two(self):
+        m1 = MetaData()
+        m2 = MetaData()
+
+        t1 = Table(
+            "foo",
+            m1,
+            Column("id", Integer, primary_key=True),
+            Column("email", String(50)),
+            Column("name", String(50)),
+        )
+        Index(
+            "email_idx",
+            func.coalesce(t1.c.email, t1.c.name).desc(),
+            unique=True,
+        )
+
+        t2 = Table(
+            "foo",
+            m2,
+            Column("id", Integer, primary_key=True),
+            Column("email", String(50)),
+            Column("name", String(50)),
+        )
+        Index(
+            "email_idx",
+            func.coalesce(t2.c.email, t2.c.name).desc(),
+            unique=True,
+        )
+
+        with expect_warnings(*self._functional_index_warn()):
+            diffs = self._fixture(m1, m2)
+        eq_(diffs, [])
